@@ -173,12 +173,10 @@ class TaskLoop:
         self.time_pause = kwargs.get('time_pause', .1)
 
     def __str__(self):
-        return f'''Taskloop {self.name},
-        coro {self.coro}, args {self.coro_args},
-        kwargs {self.coro_kwargs}'''
+        return f'''Taskloop {self.name}, coro {self.coro}'''
 
     def __repr__(self):
-        return f"Taskloop({self.coro},{self.coro_args},{self.coro_kwargs})"
+        return f"Taskloop({self.coro},{self.name})"
 
     def close(self):
         task = asyncio.current_task()
